=======================================
Gaussian-Process Factor Analysis (GPFA)
=======================================

.. automodule:: elephant.gpfa.gpfa


References
----------

.. bibliography:: ../bib/elephant.bib
   :labelprefix: gpfa
   :keyprefix: gpfa-
   :style: unsrt
